library(testthat)
library(startR)
context("Generic tests")
test_that("Sanity checks", {

#============= 1 ===============
#-----ex1_1_transform.R-------

obs_path <- '/esarchive/recon/ecmwf/era5/monthly_mean/$var$_f1h/$var$_$sdate$.nc'

obs <- Start(dat = obs_path,
             var = 'sfcWind',
             sdate = '201811',
             time = 'all',
             latitude = values(list(0, 10)),
             latitude_reorder = Sort(),
             longitude = values(list(0, 10)),
             synonims = list(longitude = c('lon', 'longitude'),
                             latitude = c('lat', 'latitude')),
             transform = CDORemapper,
             transform_extra_cells = 2,
             transform_params = list(grid = 'r360x181',
                                     method = 'conservative',
                                     crop = c(0, 10, 0, 10)),
             transform_vars = c('latitude', 'longitude'),
             return_vars = list(time = NULL,
                                latitude = 'dat',
                                longitude = 'dat'),
             split_multiselected_dims = TRUE,
             merge_across_dims = TRUE,
             retrieve = T)

  expect_equal(
    dim(obs),
    c(dat = 1, var = 1, sdate = 1, time = 1, latitude = 11, longitude = 11)
  )

  expect_equal(
    as.vector(summary(obs)),
    c(1.090, 1.684, 2.426, 2.728, 3.706, 4.970)
  )

#============= 2 ===============

obs <- Start(dat = obs_path,
             var = 'sfcWind',
             sdate = '201811',
             time = 'all',
             latitude = indices(1:10),
             latitude_reorder = Sort(),
             longitude = indices(1:10),
             synonims = list(longitude = c('lon', 'longitude'),
                             latitude = c('lat', 'latitude')),
             transform = CDORemapper,
             transform_extra_cells = 2,
             transform_params = list(grid = 'r360x181',
                                     method = 'conservative'),
                                     #crop = c(0, 10, 0, 10)),
             transform_vars = c('latitude', 'longitude'),
             return_vars = list(time = NULL,
                                latitude = 'dat',
                                longitude = 'dat'),
             split_multiselected_dims = TRUE,
             merge_across_dims = TRUE,
             retrieve = T)
  expect_equal(
    dim(obs),
    c(dat = 1, var = 1, sdate = 1, time = 1, latitude = 10, longitude = 10)
  )
  expect_equal(
    length(which(!is.na(obs[1,1,1,1,,]))),
    6
  )
  expect_equal(
    mean(obs[1,1,1,1,,],1, na.rm = T),
    5.047489
  )





})
